@@ -16,7 +16,7 @@
 #endif
   def (name)
   def (title)
-#ifdef XPM_BACKGROUND
+#ifdef BG_IMAGE_FROM_FILE
   def (path)
   def (backgroundPixmap)
 #endif
@@ -62,6 +62,7 @@
 #endif
 #ifdef ENABLE_TRANSPARENCY
   def (transparent)
+  def (shade)
 #endif
 #if XFT
   def (depth)
@@ -102,9 +103,6 @@
 #ifdef OFF_FOCUS_FADING
   def (fade)
 #endif
-#ifdef TINTING
-  def (shade)
-#endif
 #if ENABLE_PERL
   def (perl_eval)
   def (perl_ext_1)
