@@ -28,6 +28,9 @@ thus must be encoded as UTF-8.
 Each script will only ever be loaded once, even in @@RXVT_NAME@@d, where
 scripts will be shared (but not enabled) for all terminals.
 
+You can disable the embedded perl interpreter by setting both "perl-ext"
+and "perl-ext-common" resources to the empty string.
+
 =head1 PREPACKAGED EXTENSIONS
 
 This section describes the extensions delivered with this release. You can
@@ -151,7 +154,7 @@ search upwards/downwards in the scrollback buffer, C<End> jumps to the
 bottom. C<Escape> leaves search mode and returns to the point where search
 was started, while C<Enter> or C<Return> stay at the current position and
 additionally stores the first match in the current line into the primary
-selection.
+selection if the C<Shift> modifier is active.
 
 The regex defaults to "(?i)", resulting in a case-insensitive search. To
 get a case-sensitive search you can delete this prefix using C<BackSpace>
@@ -258,10 +261,14 @@ C<matcher.pattern.0> resource, and additional patterns can be specified
 with numbered patterns, in a manner similar to the "selection" extension.
 The launcher can also be overridden on a per-pattern basis.
 
+It is possible to activate the most recently seen match from the keyboard.
+Simply bind a keysym to "perl:matcher" as seen in the example below.
+
 Example configuration:
 
     URxvt.perl-ext:           default,matcher
     URxvt.urlLauncher:        sensible-browser
+    URxvt.keysym.C-Delete:    perl:matcher
     URxvt.matcher.button:     1
     URxvt.matcher.pattern.1:  \\bwww\\.[\\w-]+\\.[\\w./?&@#-]*[\\w/-]
     URxvt.matcher.pattern.2:  \\B(/\\S+?):(\\d+)(?=:|$)
@@ -307,6 +314,10 @@ supported in this mode. Example:
 
    @@RXVT_NAME@@ -pixmap background.xpm -pe automove-background
 
+L<http://wiki.archlinux.org/index.php/Perl_Background_Rotation/Extensions>
+shows how this extension can be used to implement an automatically blurred
+transparent background.
+
 =item block-graphics-to-ascii
 
 A not very useful example of filtering all text output to the terminal
@@ -992,6 +1003,31 @@ sub SET_COLOR($$$) {
    SET_BGCOLOR (SET_FGCOLOR ($_[0], $_[1]), $_[2])
 }
 
+sub rend2mask {
+   no strict 'refs';
+   my ($str, $mask) = (@_, 0);
+   my %color = ( fg => undef, bg => undef );
+   my @failed;
+   for my $spec ( split /\s+/, $str ) {
+      if ( $spec =~ /^([fb]g)[_:-]?(\d+)/i ) {
+         $color{lc($1)} = $2;
+      } else {
+         my $neg = $spec =~ s/^[-^]//;
+         unless ( exists &{"RS_$spec"} ) {
+            push @failed, $spec;
+            next;
+         }
+         my $cur = &{"RS_$spec"};
+         if ( $neg ) {
+            $mask &= ~$cur;
+         } else {
+            $mask |= $cur;
+         }
+      }
+   }
+   ($mask, @color{qw(fg bg)}, \@failed)
+}
+
 # urxvt::term::extension
 
 package urxvt::term::extension;
@@ -1956,11 +1992,6 @@ sub DESTROY {
 
 package urxvt::watcher;
 
-@urxvt::timer::ISA = __PACKAGE__;
-@urxvt::iow::ISA   = __PACKAGE__;
-@urxvt::pw::ISA    = __PACKAGE__;
-@urxvt::iw::ISA    = __PACKAGE__;
-
 =head2 The C<urxvt::timer> Class
 
 This class implements timer watchers/events. Time is represented as a
@@ -2155,3 +2186,5 @@ numbers indicate more verbose output.
 =cut
 
 1
+
+# vim: sw=3:
